package Task::BeLike::DCANTRELL;

$VERSION = '1';

=head1 NAME

Task::BeLike::DCANTRELL - Install the modules that DCANTRELL thinks you should use

=head1 SYNOPSIS

    cpanm Task::BeLike::DCANTRELL

=head1 AUTHOR, COPYRIGHT and LICENCE

Copyright 2025 David Cantrell E<lt>F<david@cantrell.org.uk>E<gt>

This software is free-as-in-speech software, and may be used,
distributed, and modified under the terms of either the GNU
General Public Licence version 2 or the Artistic Licence. It's
up to you which one you use. The full text of the licences can
be found in the files GPL2.txt and ARTISTIC.txt, respectively.

=head1 CONSPIRACY

This module is also free-as-in-mason software.

=cut
